@@ -8,7 +8,7 @@
 
 BEGIN { $| = 1; print "1..2\n"; }
 END {print "not ok 1\n" unless $loaded;}
-use Gimp qw( interface=lib :auto );
+use Gimp qw( :auto );
 $loaded = 1;
 print "ok 1\n";
 
